#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_EPS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_EPS_HPP_INCLUDED

#include <boost/simd/constant/include/constants/eps.hpp>

#endif
